# Changelog – Standard Open Arm-100 5DOF - Version 1.3 Description

All notable changes to this model will be documented in this file.

## [2025-06-09]
- Adjusted joint limits to match real robot's physical constraints.
- Changed primary color of robot to white.
- Added rest position keyframe.

## [2024-11-25]
- Initial release.
